TMSecondaryHeader

Struct TMSecondaryHeader 

pub struct TMSecondaryHeader {
    pub tfvn: u8,
    pub data_field: Vec<u8>,
}
Available on crate feature tctm only.
A flexible Platform for the Secondary Header in a TM Transfer Frame. This secondary header computes the length of the Secondary Header Payload at en/de-coding time, as such it should only be used along with a TMTransferFrame to ensure correctness.

Fields

tfvn: u8

The version number of the secondary header CCSDS 132.0-B-3 recognizes only one version, which is Version 1, the binary encoded Version Number of which is ‘00’.

data_field: Vec<u8>

The data Field of the secondary header contains mission specific information. Maximum length is 63 bytes.

Implementations

Source

impl TMSecondaryHeader

pub fn validate(&self) -> Result<(), Error>

Validate header values which require bit masks will fit in the desginate bit-depth.

Errors:

pub fn encode(self) -> Vec<u8>

Encode to a byte steam

pub fn decode<R: Read>(buffer: &mut R) -> Result<Self, Error>

Decode from a byte steam