pub struct TMSecondaryHeader {
pub tfvn: u8,
pub data_field: Vec<u8>,
}Available on crate feature
tctm only.Expand description
A flexible Platform for the Secondary Header in a TM Transfer Frame. This secondary header computes the length of the Secondary Header Payload at en/de-coding time, as such it should only be used along with a TMTransferFrame to ensure correctness.
Fields
tfvn: u8The version number of the secondary header CCSDS 132.0-B-3 recognizes only one version, which is Version 1, the binary encoded Version Number of which is ‘00’.
data_field: Vec<u8>The data Field of the secondary header contains mission specific information. Maximum length is 63 bytes.
Implementations
Sourceimpl TMSecondaryHeader
impl TMSecondaryHeader
Sourcepub fn validate(&self) -> Result<(), Error>
pub fn validate(&self) -> Result<(), Error>
Validate header values which require bit masks will fit in the desginate bit-depth.
Errors:
- if Self::tfvn > 3
- if Self::data_field has length > 63